Macro communicator_generics_placeholders
communicator_generics_placeholders!() { /* proc-macro */ }Expand description
Inserts as many blanks as generics were used to create the communicator struct by build_communicator!.
communicator_generics_placeholders!() { /* proc-macro */ }Inserts as many blanks as generics were used to create the communicator struct by build_communicator!.