Struct NewtonDamped2DF32
pub struct NewtonDamped2DF32 {
pub pos: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>,
pub vel: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>,
pub damping_constant: f32,
pub mass: f32,
}Available on crate feature
cpu_os_threads only.Expand description
Newtonian dynamics governed by mass and damping.
Parameters
| Symbol | Parameter | Description |
|---|---|---|
| $\vec{x}$ | pos | Position of the particle. |
| $\dot{\vec{x}}$ | vel | Velocity of the particle. |
| $\lambda$ | damping | Damping constant |
| $m$ | mass | Mass of the particle. |
Equations
The equation of motion is given by \begin{equation} m \ddot{\vec{x}} = \vec{F} - \lambda \dot{\vec{x}} \end{equation} where $\vec{F}$ is the force as calculated by the Interaction trait.
Comments
If the cell is growing, we need to increase the mass $m$. By interacting with the outside world, we can adapt $\lambda$ to external values although this is rarely desirable. Both operations need to be implemented by other concepts such as Cycle.
Fields
pos: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>Current position $\vec{x}$ given by a vector of dimension D.
vel: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>Current velocity $\dot{\vec{x}}$ given by a vector of dimension D.
damping_constant: f32Damping constant $\lambda$.
mass: f32Mass $m$ of the object.
Implementations
impl NewtonDamped2DF32
impl NewtonDamped2DF32
impl NewtonDamped2DF32
impl NewtonDamped2DF32
pub fn get_damping_constant(&self) -> f32
pub fn get_damping_constant(&self) -> f32
[pyo3] getter for damping_constant
pub fn set_damping_constant(&mut self, damping_constant: f32)
pub fn set_damping_constant(&mut self, damping_constant: f32)
[pyo3] setter for damping_constant