Struct NewtonDamped3D
pub struct NewtonDamped3D {
pub pos: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>,
pub vel: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>,
pub damping_constant: f64,
pub mass: f64,
}Available on crate feature
cpu_os_threads only.Expand description
Newtonian dynamics governed by mass and damping.
Parameters
| Symbol | Parameter | Description |
|---|---|---|
| $\vec{x}$ | pos | Position of the particle. |
| $\dot{\vec{x}}$ | vel | Velocity of the particle. |
| $\lambda$ | damping | Damping constant |
| $m$ | mass | Mass of the particle. |
Equations
The equation of motion is given by \begin{equation} m \ddot{\vec{x}} = \vec{F} - \lambda \dot{\vec{x}} \end{equation} where $\vec{F}$ is the force as calculated by the Interaction trait.
Comments
If the cell is growing, we need to increase the mass $m$. By interacting with the outside world, we can adapt $\lambda$ to external values although this is rarely desirable. Both operations need to be implemented by other concepts such as Cycle.
Fields
pos: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>Current position $\vec{x}$ given by a vector of dimension D.
vel: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>Current velocity $\dot{\vec{x}}$ given by a vector of dimension D.
damping_constant: f64Damping constant $\lambda$.
mass: f64Mass $m$ of the object.
Implementations
impl NewtonDamped3D
impl NewtonDamped3D
impl NewtonDamped3D
impl NewtonDamped3D
pub fn get_damping_constant(&self) -> f64
pub fn get_damping_constant(&self) -> f64
[pyo3] getter for damping_constant
pub fn set_damping_constant(&mut self, damping_constant: f64)
pub fn set_damping_constant(&mut self, damping_constant: f64)
[pyo3] setter for damping_constant