Struct PlottingConfig
pub struct PlottingConfig {
pub image_size: u32,
pub n_threads: Option<usize>,
pub image_type: ImageType,
pub show_progressbar: bool,
}Available on crate feature
cpu_os_threads only.Expand description
Contains settings for plotting results.
Fields
image_size: u32Image size in pixels. The plotting function of the underlying simulation domain may choose to modifiy this parameter.
n_threads: Option<usize>The number of threads used for plotting. Notice that this number is not the same as in SimulationMetaParams.
image_type: ImageTypeThe ImageType to export.
show_progressbar: boolShows a progressbar while exporting images.