Struct StorageBuilder
pub struct StorageBuilder<const INIT: bool = false> { /* private fields */ }cpu_os_threads only.Expand description
Used to construct a StorageManager
This builder contains multiple options which can be used to configure the location and type in which results are stored. To get an overview over all possible options, we refer to the module documentation.
use cellular_raza_core::storage::{StorageBuilder, StorageOption};
let storage_priority = StorageOption::default_priority();
let storage_builder = StorageBuilder::new()
.priority(storage_priority)
.location("./");Implementations
impl<const INIT: bool> StorageBuilder<INIT>
impl<const INIT: bool> StorageBuilder<INIT>
pub fn priority(
self,
priority: impl IntoIterator<Item = StorageOption>,
) -> StorageBuilder<INIT>
pub fn priority( self, priority: impl IntoIterator<Item = StorageOption>, ) -> StorageBuilder<INIT>
Define the priority of StorageOption. See StorageOption::default_priority.
pub fn get_priority(&self) -> UniqueVec<StorageOption>
pub fn get_priority(&self) -> UniqueVec<StorageOption>
Get the current priority
pub fn suffix(self, suffix: impl Into<PathBuf>) -> StorageBuilder<INIT>
pub fn suffix(self, suffix: impl Into<PathBuf>) -> StorageBuilder<INIT>
Define a suffix which will be appended to the save path
pub fn get_suffix(&self) -> PathBuf
pub fn get_suffix(&self) -> PathBuf
Get the current suffix
pub fn add_date(self, add_date: bool) -> StorageBuilder<INIT>
pub fn add_date(self, add_date: bool) -> StorageBuilder<INIT>
Store results by their current date inside the specified folder path
pub fn get_add_date(&self) -> bool
pub fn get_add_date(&self) -> bool
Get information if the current date should be appended to the storage path
impl StorageBuilder
impl StorageBuilder
pub fn new() -> StorageBuilder
pub fn new() -> StorageBuilder
Constructs a new StorageBuilder with default settings.
use cellular_raza_core::storage::StorageBuilder;
let storage_builder = StorageBuilder::new();pub fn init(self) -> StorageBuilder<true>
pub fn init(self) -> StorageBuilder<true>
Initializes the StorageBuilder thus filling information about time.
pub fn init_with_date(self, date: &Path) -> StorageBuilder<true>
pub fn init_with_date(self, date: &Path) -> StorageBuilder<true>
Specify the time at which the results should be saved
pub fn location<P>(self, location: P) -> StorageBuilder
pub fn location<P>(self, location: P) -> StorageBuilder
Define a folder where to store results
Note that this functionality is only available as long as the StorageBuilder has not been initialized.
pub fn get_location(&self) -> PathBuf
pub fn get_location(&self) -> PathBuf
Get the current storage_location
Note that this functionality is only available as long as the StorageBuilder has not been initialized.
impl StorageBuilder<true>
impl StorageBuilder<true>
pub fn get_full_path(&self) -> PathBuf
pub fn get_full_path(&self) -> PathBuf
Get the fully constructed path after the Builder has been initialized with the StorageBuilder::init function.
pub fn de_init(self) -> StorageBuilder
pub fn de_init(self) -> StorageBuilder
De-initializes the StorageBuilder, making it possible to edit it again.