Struct Strategies
pub struct Strategies<'a, Vox>where
Vox: 'a + Clone,{
pub voxel_definition_strategies: &'a dyn Fn(&mut Vox),
}Available on crate feature
cpu_os_threads only.Expand description
Contains methods to modify voxels when initializing the simulation domain.
Fields
voxel_definition_strategies: &'a dyn Fn(&mut Vox)Strategies for the modification of existing voxels before the simulation has started.