Struct TimeSetup
pub struct TimeSetup {
pub t_start: f64,
pub t_eval: Vec<(f64, bool)>,
}Available on crate feature
cpu_os_threads only.Expand description
Contains information about the discretization of time and when to save results.
Fields
t_start: f64Initial time point of the simulation.
t_eval: Vec<(f64, bool)>Time points at which to evaluate the simulation. The additional bool determines if we also save the results.