Type Alias PlainIndex
pub type PlainIndex = usize;Available on crate feature
cpu_os_threads only.Expand description
This is a purely implementational detail and should not be of any concern to the end user.
pub type PlainIndex = usize;cpu_os_threads only.This is a purely implementational detail and should not be of any concern to the end user.