Struct CartesianCuboid2
pub struct CartesianCuboid2 { /* private fields */ }Available on crate feature
elli only.Expand description
Cuboid Domain with regular cartesian coordinates in
2D
Implementations
impl CartesianCuboid2
impl CartesianCuboid2
pub fn from_boundaries_and_interaction_ranges(
min: [f64; 2],
max: [f64; 2],
interaction_ranges: [f64; 2],
) -> Result<CartesianCuboid2, CalcError>
Available on crate feature cpu_os_threads only.
pub fn from_boundaries_and_interaction_ranges( min: [f64; 2], max: [f64; 2], interaction_ranges: [f64; 2], ) -> Result<CartesianCuboid2, CalcError>
cpu_os_threads only.Builds a new CartesianCuboid2 from given boundaries and maximum interaction ranges of the containing
cells.
pub fn from_boundaries_and_n_voxels(
min: [f64; 2],
max: [f64; 2],
n_vox: [usize; 2],
) -> Result<CartesianCuboid2, CalcError>
Available on crate feature cpu_os_threads only.
pub fn from_boundaries_and_n_voxels( min: [f64; 2], max: [f64; 2], n_vox: [usize; 2], ) -> Result<CartesianCuboid2, CalcError>
cpu_os_threads only.Builds a new CartesianCuboid2 from given boundaries and the number of voxels per dimension specified.