Enum SimulationError

pub enum SimulationError {
Show 16 variants CalcError(CalcError), DecomposeError(DecomposeError), TimeError(TimeError), ControllerError(ControllerError), DivisionError(DivisionError), DeathError(DeathError), BoundaryError(BoundaryError), DrawingError(DrawingError), IndexError(IndexError), SendError(String), ReceiveError(RecvError), StorageError(StorageError), IoError(Error), RngError(RngError), OtherThreadError(String), Pyo3Error(PyErr),
}
Available on crate feature chili only.
Covers all errors that can occur in this Simulation The errors are listed from very likely to be a user error from almost certainly an internal error.

Categorization of errors

Some errors are more likely to be occurring due to an incorrect usage by an end user while others are highly likely to be due to some internal implementation problem. Independent of the exact reason, why they are occurring, some can be handled explicitly while others force an abort of the simulation. See also HandlingStrategy.

VariantConcept ImplementationEngine-FaultTime Increment
CalcError8/102/100/10
DecomposeError7/103/100/10
ControllerError8/101/101/10
DivisionError8/101/101/10
DeathError8/101/101/10
BoundaryError7/101/102/10
DrawingError9/101/100/10
IndexError6/102/102/10
SendError3/106/101/10
ReceiveError3/106/101/10
StorageError3/107/100/10
RngError1/108/101/10
IoError1/109/100/10

Variants



CalcError(CalcError)

Occurs during calculations of any mathematical update steps such as Interaction between cells.



DecomposeError(DecomposeError)

Error associated to splitting up the simulation domain into chunks in order to effectively process it in parallel.



TimeError(TimeError)

Related to time-stepping events. See crate::time.



ControllerError(ControllerError)

Error-type specifically related to the Controller trait.



DivisionError(DivisionError)

An error specific to cell-division events by the

Cycle trait.



DeathError(DeathError)

Related to the PhasedDeath event. This error can only occcurr during the update_conditional_phased_death method.



BoundaryError(BoundaryError)

Enforcing boundary conditions on cells can exhibhit this boundary error.



DrawingError(DrawingError)



IndexError(IndexError)

Mostly caused by trying to find a voxel by its index. This error can also occcurr when applying too large simulation-steps.



SendError(String)

Sending information between threads fails



ReceiveError(RecvError)

Receiving information from another thread fails



StorageError(StorageError)

Storing results fails



IoError(Error)

When writing to output files or reading from them. See std::io::Error



RngError(RngError)

Error related to random number generation by the rand_chacha::ChaCha8Rng struct.



OtherThreadError(String)

Only occurs when another thread returns an error



Pyo3Error(PyErr)

Error related to [pyo3]