Struct Bacteria
pub struct Bacteria {
pub mechanics: NewtonDamped2D,
pub cycle: BacteriaCycle,
pub cellular_reactions: BacteriaReactions,
pub interactionextracellulargradient: GradientSensing,
}Expand description
Bacteria-Agent as used in the pool-model example
Fields
mechanics: NewtonDamped2DSee NewtonDamped2D mechanics
cycle: BacteriaCycleSee BacteriaCycle
cellular_reactions: BacteriaReactionsinteractionextracellulargradient: GradientSensingSee GradientSensing
Implementations
impl Bacteria
impl Bacteria
pub fn from(
py: Python<'_>,
bacteria_template: BacteriaTemplate,
) -> Result<Bacteria, PyErr>
Available on crate feature cpu_os_threads only.
pub fn from( py: Python<'_>, bacteria_template: BacteriaTemplate, ) -> Result<Bacteria, PyErr>
cpu_os_threads only.Convert a BacteriaTemplate into a Bacteria
pub fn volume_to_mass(&self, volume: f64) -> f64
Available on crate feature cpu_os_threads only.
pub fn volume_to_mass(&self, volume: f64) -> f64
cpu_os_threads only.We can have a look at this paper https://doi.org/10.1128/jb.148.1.58-63.1981 and see that the average density of E.Coli is between 1.080 and 1.100 g/ml This means we can safely set the density to 1.09
pub fn mass_to_volume(&self, mass: f64) -> f64
Available on crate feature cpu_os_threads only.
pub fn mass_to_volume(&self, mass: f64) -> f64
cpu_os_threads only.Conversion function of mass to volume
pub fn increase_volume(&mut self, volume_increment: f64)
Available on crate feature cpu_os_threads only.
pub fn increase_volume(&mut self, volume_increment: f64)
cpu_os_threads only.Modifies the cell and increases the overall volume by the specified amount.
pub fn cell_radius(&self) -> f64
Available on crate feature cpu_os_threads only.
pub fn cell_radius(&self) -> f64
cpu_os_threads only.Obtain the current cell radius