Struct BacteriaTemplate
pub struct BacteriaTemplate {
pub mechanics: Py<NewtonDamped2D>,
pub cycle: Py<BacteriaCycle>,
pub cellular_reactions: Py<BacteriaReactions>,
pub interactionextracellulargradient: Py<GradientSensing>,
}Expand description
This template can be used in order to build a Bacteria object from it.
It contains heap-allocated instances of the python classes for the individual aspects. This is useful when modifying said properties from python directly via dot-notation.
Fields
mechanics: Py<NewtonDamped2D>See NewtonDamped2D mechanics
cycle: Py<BacteriaCycle>See BacteriaCycle
cellular_reactions: Py<BacteriaReactions>interactionextracellulargradient: Py<GradientSensing>See GradientSensing
Implementations
impl BacteriaTemplate
impl BacteriaTemplate
pub fn default(py: Python<'_>) -> Result<BacteriaTemplate, PyErr>
Available on crate feature cpu_os_threads only.
pub fn default(py: Python<'_>) -> Result<BacteriaTemplate, PyErr>
cpu_os_threads only.Constructs the default bacteria template by using default values for every field in the struct.