Struct ReactionsContactInformation
pub struct ReactionsContactInformation<Pos, Ri, RInf> {
pub pos: Pos,
pub intracellular: Ri,
pub info: RInf,
pub cell_index_in_vector: usize,
pub index_sender: VoxelPlainIndex,
pub index_receiver: VoxelPlainIndex,
}Available on crate feature
chili only.Expand description
This information will be sent from one cell to another to determine their combined reactions.
Fields
pos: PosCurrent position
intracellular: RiCurrent intracellular values
info: RInfInformation shared between cells
cell_index_in_vector: usizeIndex of cell in stored vector
When returning information, this property is needed in order to get the correct cell in the vector of cells and update its properties.
index_sender: VoxelPlainIndexVoxel index of the sending cell. Information should be returned to this voxel.
index_receiver: VoxelPlainIndexVoxel index of the voxel from which information is requested. This index is irrelevant after the initial query has been sent.