Struct SimulationRunner
pub struct SimulationRunner<I, Sb> {
pub subdomain_boxes: BTreeMap<I, Sb>,
}Available on crate feature
chili only.Expand description
Intermediate object which gets consumed once the simulation is run
This Setup contains structural information needed to run a simulation. In the future, we hope to change the types stored in this object to simple iterators and non-allocating types in general.
Fields
subdomain_boxes: BTreeMap<I, Sb>One SubDomainBox represents one single thread over which we are parallelizing our simulation.