Struct Voxel
pub struct Voxel<C, A> {
pub plain_index: VoxelPlainIndex,
pub neighbors: BTreeSet<VoxelPlainIndex>,
pub cells: Vec<(CellBox<C>, A)>,
pub new_cells: Vec<(C, Option<CellIdentifier>)>,
pub id_counter: u64,
pub rng: ChaCha8Rng,
}Available on crate feature
chili only.Expand description
Stores information related to a voxel of the physical simulation domain.
Fields
plain_index: VoxelPlainIndexThe index which is given when decomposing the domain and all indices are counted.
neighbors: BTreeSet<VoxelPlainIndex>Indices of neighboring voxels
cells: Vec<(CellBox<C>, A)>Cells currently in the voxel
new_cells: Vec<(C, Option<CellIdentifier>)>New cells which are about to be included into this voxels cells.
id_counter: u64A counter to make sure that each Id of a cell is unique.
rng: ChaCha8RngA random number generator which is unique to this voxel and thus able to produce repeatable results even for parallelized simulations.