Struct DefaultCallsite
pub struct DefaultCallsite { /* private fields */ }Expand description
A default Callsite implementation.
Implementations
impl DefaultCallsite
impl DefaultCallsite
pub const fn new(meta: &'static Metadata<'static>) -> DefaultCallsite
Available on crate feature cpu_os_threads only.
pub const fn new(meta: &'static Metadata<'static>) -> DefaultCallsite
cpu_os_threads only.Returns a new DefaultCallsite with the specified Metadata.
pub fn register(&'static self) -> Interest
Available on crate feature cpu_os_threads only.
pub fn register(&'static self) -> Interest
cpu_os_threads only.Registers this callsite with the global callsite registry.
If the callsite is already registered, this does nothing. When using
DefaultCallsite, this method should be preferred over
tracing_core::callsite::register, as it ensures that the callsite is
only registered a single time.
Other callsite implementations will generally ensure that callsites are not re-registered through another mechanism.
See the documentation on callsite registration for details on the global callsite registry.