Struct Field
pub struct Field { /* private fields */ }Expand description
An opaque key allowing O(1) access to a field in a Span’s key-value
data.
As keys are defined by the metadata of a span, rather than by an individual instance of a span, a key may be used to access the same field across all instances of a given span with the same metadata. Thus, when a subscriber observes a new span, it need only access a field by name once, and use the key for that name for all other accesses.
Implementations
impl Field
impl Field
pub fn callsite(&self) -> Identifier
Available on crate feature cpu_os_threads only.
pub fn callsite(&self) -> Identifier
cpu_os_threads only.Returns an Identifier that uniquely identifies the Callsite
which defines this field.