Struct Record
pub struct Record<'a> { /* private fields */ }Expand description
A set of fields recorded by a span.
Implementations
impl<'a> Record<'a>
impl<'a> Record<'a>
pub fn new(values: &'a ValueSet<'a>) -> Record<'a>
Available on crate feature cpu_os_threads only.
pub fn new(values: &'a ValueSet<'a>) -> Record<'a>
cpu_os_threads only.Constructs a new Record from a ValueSet.
pub fn record(&self, visitor: &mut dyn Visit)
Available on crate feature cpu_os_threads only.
pub fn record(&self, visitor: &mut dyn Visit)
cpu_os_threads only.Records all the fields in this Record with the provided Visitor.
pub fn len(&self) -> usize
Available on crate feature cpu_os_threads only.
pub fn len(&self) -> usize
cpu_os_threads only.Returns the number of fields that would be visited from this Record
when Record::record() is called