Struct Interest
pub struct Interest(/* private fields */);Expand description
Indicates a Subscriber’s interest in a particular callsite.
Subscribers return an Interest from their register_callsite methods
in order to determine whether that span should be enabled or disabled.
Implementations
impl Interest
impl Interest
pub fn never() -> Interest
Available on crate feature cpu_os_threads only.
pub fn never() -> Interest
cpu_os_threads only.Returns an Interest indicating that the subscriber is never interested
in being notified about a callsite.
If all active subscribers are never() interested in a callsite, it will
be completely disabled unless a new subscriber becomes active.
pub fn sometimes() -> Interest
Available on crate feature cpu_os_threads only.
pub fn sometimes() -> Interest
cpu_os_threads only.Returns an Interest indicating the subscriber is sometimes interested
in being notified about a callsite.
If all active subscribers are sometimes or never interested in a
callsite, the currently active subscriber will be asked to filter that
callsite every time it creates a span. This will be the case until a new
subscriber expresses that it is always interested in the callsite.
pub fn always() -> Interest
Available on crate feature cpu_os_threads only.
pub fn always() -> Interest
cpu_os_threads only.Returns an Interest indicating the subscriber is always interested in
being notified about a callsite.
If any subscriber expresses that it is always() interested in a given
callsite, then the callsite will always be enabled.
pub fn is_never(&self) -> bool
Available on crate feature cpu_os_threads only.
pub fn is_never(&self) -> bool
cpu_os_threads only.Returns true if the subscriber is never interested in being notified
about this callsite.
pub fn is_sometimes(&self) -> bool
Available on crate feature cpu_os_threads only.
pub fn is_sometimes(&self) -> bool
cpu_os_threads only.Returns true if the subscriber is sometimes interested in being notified
about this callsite.